==> goai-module-translator-1.1.0-89247b.zip: CHANGELOG.md <==
### 0.0.1 - 26.04.2025

- Module skeleton created
- Base system configuration added
- Implemented a configuration helper
- Implemented a new DB schema (it includes two tables to store information about translations)
- Implemented interfaces, repositories, and models for the new DB schema

### 0.0.2 - 27.04.2025

- Implement an option source classes related to entity type, translation type
- Implement an interface and a factory that will allow to handle different type of entities based on key

### 0.0.3 - 30.04.2025

- Prepare and test connector that allow to work with AI translation service.
- Implement logic to collect and preprocess product data for request, post processing of request result and custom options.
- Implement an attribute based restrictions (new field for attributes).

### 0.0.4 - 01.05.2025

- Implement an attribute based restrictions for product processor.
- Implement an attribute-based restrictions for category processor. Implement flag to restrict attribute options and label translation.
- Implement a specific attribute labels processor

### 0.0.5 - 05.05.2025

- Optimise attribute collection logic for products and categories.
- Implement an queue that will collect data about entity and send it to the connector using factory  + process response
- Implement a cron that will collect a list of rows (number will be related on configuration), convert it to json and pass to a queue, improve queue processing.
- Optimise attribute collection logic for products and categories.
- Implement an event-based functionality that will add entities to the tables on translation on product, category and attribute saving
- Implement a cron-based translation table clean up once a day (clean records with translated status)

### 0.1.0 - 10.05.2025 - Beta

- Implement rewrite handling + conflict handling, solve issues with queues.

### 0.1.1 - 12.05.2025

- Remove separation for single language, prepare processor for CMS pages.

### 0.1.2 - 14.05.2025

- Implement "Default Store" configuration, implement processor for CMS pages.
- Implement logic to collect information from the default store view that set in system configuration.
- Optimize default store logic for existing processors, prepare processor for CMS blocks.

### 0.1.3 - 15.05.2025

- Implement a new grid with translation log.

### 0.2.0 - 17.05.2025

- Investigate and solve issues with too much entity ids passed into the transition queue.
- Implement a site onboarding processing + extending all existing processors with logic to collect the full list of entities that must be translated
- Implement opportunity to exclude terms (add new system configuration, pass configuration value to the request)

### 0.2.1 - 20.05.2025

- Implement progress bar for translator.
- Implement default store changing handling.
- Implement permanent redirect handling for categories and products.
- Attach user guide

### 1.0.0 - 23.05.2025 - MVP

Implemented a term replacement functionality, it includes:

- New system configurations that allow to manage term vocabulary on a store view level
- A daily cron job runs at 1:00 AM, gathers updated configurations from the past day, and replaces the specified terms accordingly.
- The replacement logic has been integrated into the existing translation process.

### 1.1.0 - 20.06.2025

- Implement translation restriction based on flag
- Implement manual trigger function for translation
- Added mass actions for translation log. It's possible to remove translation from a queue or refresh status.
- Solved issue with empty entity type configuration leading to an error.
- Solved issue with using not existing function for attributes.
- Solved issue with lost objects for CMS pages and blocks
- Solved issue with incorrect translation type for records that were added via mass insert.

==> goai-module-translator-1.3.0-22a110.zip: CHANGELOG.md <==
### 0.0.1 - 26.04.2025

- Module skeleton created
- Base system configuration added
- Implemented a configuration helper
- Implemented a new DB schema (it includes two tables to store information about translations)
- Implemented interfaces, repositories, and models for the new DB schema

### 0.0.2 - 27.04.2025

- Implement an option source classes related to entity type, translation type
- Implement an interface and a factory that will allow to handle different type of entities based on key

### 0.0.3 - 30.04.2025

- Prepare and test connector that allow to work with AI translation service.
- Implement logic to collect and preprocess product data for request, post processing of request result and custom options.
- Implement an attribute based restrictions (new field for attributes).

### 0.0.4 - 01.05.2025

- Implement an attribute based restrictions for product processor.
- Implement an attribute-based restrictions for category processor. Implement flag to restrict attribute options and label translation.
- Implement a specific attribute labels processor

### 0.0.5 - 05.05.2025

- Optimise attribute collection logic for products and categories.
- Implement an queue that will collect data about entity and send it to the connector using factory  + process response
- Implement a cron that will collect a list of rows (number will be related on configuration), convert it to json and pass to a queue, improve queue processing.
- Optimise attribute collection logic for products and categories.
- Implement an event-based functionality that will add entities to the tables on translation on product, category and attribute saving
- Implement a cron-based translation table clean up once a day (clean records with translated status)

### 0.1.0 - 10.05.2025 - Beta

- Implement rewrite handling + conflict handling, solve issues with queues.

### 0.1.1 - 12.05.2025

- Remove separation for single language, prepare processor for CMS pages.

### 0.1.2 - 14.05.2025

- Implement "Default Store" configuration, implement processor for CMS pages.
- Implement logic to collect information from the default store view that set in system configuration.
- Optimize default store logic for existing processors, prepare processor for CMS blocks.

### 0.1.3 - 15.05.2025

- Implement a new grid with translation log.

### 0.2.0 - 17.05.2025

- Investigate and solve issues with too much entity ids passed into the transition queue.
- Implement a site onboarding processing + extending all existing processors with logic to collect the full list of entities that must be translated
- Implement opportunity to exclude terms (add new system configuration, pass configuration value to the request)

### 0.2.1 - 20.05.2025

- Implement progress bar for translator.
- Implement default store changing handling.
- Implement permanent redirect handling for categories and products.
- Attach user guide

### 1.0.0 - 23.05.2025 - MVP

Implemented a term replacement functionality, it includes:

- New system configurations that allow to manage term vocabulary on a store view level
- A daily cron job runs at 1:00 AM, gathers updated configurations from the past day, and replaces the specified terms accordingly.
- The replacement logic has been integrated into the existing translation process.

### 1.1.0 - 20.06.2025

- Implement translation restriction based on flag
- Implement manual trigger function for translation
- Added mass actions for translation log. It's possible to remove translation from a queue or refresh status.
- Solved issue with empty entity type configuration leading to an error.
- Solved issue with using not existing function for attributes.
- Solved issue with lost objects for CMS pages and blocks
- Solved issue with incorrect translation type for records that were added via mass insert.

### 1.1.1 - 23.06.2025

- Solved issue with empty options list

### 1.1.3 - 03.07.2025

- Solve issue with broken All Stores page
- Added sender logs
- Updated cron schedule for term replacement

### 1.2.0 - 04.07.2025

- Added validation for entity ID in the response. It will lead to a specific error in case if it's lost.
- Update Store Validation for CMS Pages and CMS Blocks

### 1.2.2 - 04.07.2025

- Optimize content structure to work with AI

### 1.2.3 - 09.07.2025

- Solve issue with translation started before entity was saved

### 1.2.4 - 10.07.2025

- Solve issue with category that collects cached information

### 1.2.5 - 24.07.2025

- Solve issue with incorrect batch size logic

### 1.3.0 - 28.07.2025

- Added logic for correct URL processing
- Updated logic to collect EAV attributes data for translation
- Added lost identifier validator for CMS pages and CMS blocks
